@@ -1,23 +1,32 @@
-/* Copyright (c) 2003-2006 MySQL AB
-   Use is subject to license terms
+/*
+   Copyright (c) 2003, 2021, Oracle and/or its affiliates.
+    All rights reserved. Use is subject to license terms.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA */
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
 
 #ifndef NDB_ERROR_HPP
 #define NDB_ERROR_HPP
 
-#include <ndberror.h>
+#include "ndberror.h"
 
 /**
  * @struct NdbError
@@ -206,6 +215,7 @@ struct NdbError {
    */
   const char * message;
 
+#ifndef DOXYGEN_SHOULD_SKIP_DEPRECATED
   /**
    * The detailed description.  This is extra information regarding the 
    * error which is not included in the error message.
@@ -213,6 +223,7 @@ struct NdbError {
    * @note Is NULL when no details specified
    */
   char * details;
+#endif
 
 #ifndef DOXYGEN_SHOULD_SKIP_INTERNAL
   NdbError(){
